@@ -1,4 +1,5 @@
 """ A Mixin for Response submissions. """
+import copy
 import json
 import logging
 import os
@@ -578,7 +579,8 @@ class SubmissionMixin:
         """
         return file_upload_api.get_student_file_key(self.get_student_item_dict(), index=num)
 
-    def _get_url_by_file_key(self, key):
+    @classmethod
+    def _get_url_by_file_key(cls, key):
         """
         Return download url for some particular file key.
 
@@ -595,7 +597,8 @@ class SubmissionMixin:
 
         return url
 
-    def get_download_urls_from_submission(self, submission):
+    @classmethod
+    def get_download_urls_from_submission(cls, submission):
         """
         Returns a download URLs for retrieving content within a submission.
 
@@ -614,7 +617,7 @@ class SubmissionMixin:
         raw_answer = submission.get('answer')
         answer = OraSubmissionAnswerFactory.parse_submission_raw_answer(raw_answer)
         for file_upload in answer.get_file_uploads(missing_blank=True):
-            file_download_url = self._get_url_by_file_key(file_upload.key)
+            file_download_url = cls._get_url_by_file_key(file_upload.key)
             if file_download_url:
                 urls.append(
                     file_upload_api.FileDescriptor(
@@ -853,8 +856,12 @@ class SubmissionMixin:
             "file_upload_response": self.file_upload_response,
             "prompts_type": self.prompts_type,
             "enable_delete_files": False,
+            "show_rubric_during_response": self.show_rubric_during_response,
         }
 
+        if self.show_rubric_during_response:
+            context['rubric_criteria'] = copy.deepcopy(self.rubric_criteria_with_labels)
+
         # Due dates can default to the distant future, in which case
         # there's effectively no due date.
         # If we don't add the date to the context, the template won't display it.
